==> haskell-x509-1.6.3-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.6.3
id: x509-1.6.3-88141428fd098325953c29fe36fd878e
key: x509_CpfmpJXFi0TIu7brfBhuFh
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-1.6.3
hs-libraries: HSx509-1.6.3-CpfmpJXFi0TIu7brfBhuFh
depends:
    asn1-encoding-0.9.3-61b8646033da9bb10b3d5eef2c9988e8
    asn1-parse-0.9.4-fd3a08c795c9c8864b1d7fa62a124c6b
    asn1-types-0.3.2-373d90c7a1b36e8b9d0fe76023835d30
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.10-0b27873a24b130f970d262828e1e69fa
    hourglass-0.2.9-d44f07201da9fd2656b62ae800dd5aa9
    memory-0.11-3a745e41fe78387f608c420e9b455d25
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.6.3-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.6.3
id: x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
key: x509_Jt1nFxQKP0d8cHOIU7gzoq
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-1.6.3
hs-libraries: HSx509-1.6.3-Jt1nFxQKP0d8cHOIU7gzoq
depends:
    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
    asn1-parse-0.9.4-7a8ff0bd98d1e72c778de11c366d8b51
    asn1-types-0.3.2-3969820adc8283f126affe054010f830
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
    hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
    memory-0.11-3a745e41fe78387f608c420e9b455d25
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
